@@ -11,9 +11,13 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Author::RWSTAUNER;
+{
+  $Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '3.107';
+}
+BEGIN {
+  $Dist::Zilla::PluginBundle::Author::RWSTAUNER::AUTHORITY = 'cpan:RWSTAUNER';
+}
 # ABSTRACT: RWSTAUNER's Dist::Zilla config
-our $VERSION = '3.106'; # VERSION
-our $AUTHORITY = 'cpan:RWSTAUNER'; # AUTHORITY
 
 use Moose;
 use List::Util qw(first); # core
@@ -40,7 +44,7 @@ use Dist::Zilla::Plugin::MinimumPerl 0.02 ();
 use Dist::Zilla::Plugin::NextRelease ();
 use Dist::Zilla::Plugin::OurPkgVersion 0.002 ();
 use Dist::Zilla::Plugin::PodWeaver ();
-use Dist::Zilla::Plugin::Prepender 1.100960 ();
+use Dist::Zilla::Plugin::Prepender 1.112280 ();
 use Dist::Zilla::Plugin::Repository 0.16 (); # deprecates github_http
 use Dist::Zilla::Plugin::ReportVersions::Tiny 1.01 ();
 use Dist::Zilla::Plugin::TaskWeaver 0.101620 ();
@@ -65,6 +69,7 @@ sub _default_attributes {
     # cpanm will choose the best place to install
     install_command => [Str  => 'cpanm -v -i .'],
     is_task         => [Bool => 0],
+    placeholder_comments => [Bool => 0],
     releaser        => [Str  => 'UploadToCPAN'],
     skip_plugins    => [Str  => ''],
     skip_prereqs    => [Str  => ''],
@@ -186,7 +191,7 @@ sub _add_bundled_plugins {
       Authority => {
         do_munging     => 1,
         do_metadata    => 1,
-        locate_comment => 1,
+        locate_comment => $self->placeholder_comments,
       }
     ],
     [
@@ -196,8 +201,13 @@ sub _add_bundled_plugins {
         format => q[%-9v %{yyyy-MM-dd'T'HH:mm:ss'Z'}d],
       }
     ],
-    'OurPkgVersion',
-    'Prepender',
+    ($self->placeholder_comments ? 'OurPkgVersion' : 'PkgVersion'),
+    [
+      Prepender => {
+        # don't prepend to tests
+        skip => '^x?t/.+',
+      }
+    ],
     ( $self->is_task
       ?  'TaskWeaver'
       # TODO: detect weaver.ini and skip 'config_plugin'?
@@ -365,7 +375,7 @@ Dist::Zilla::PluginBundle::Author::RWSTAUNER - RWSTAUNER's Dist::Zilla config
 
 =head1 VERSION
 
-version 3.106
+version 3.107
 
 =head1 SYNOPSIS
 
@@ -395,6 +405,7 @@ Possible options and their default values:
   fake_release   = 0  ; if true will use FakeRelease instead of 'releaser'
   install_command = cpanm -v -i . (passed to InstallRelease)
   is_task        = 0  ; set to true to use TaskWeaver instead of PodWeaver
+  placeholder_comments = 0 ; use '# VERSION' and '# AUTHORITY' comments
   releaser       = UploadToCPAN
   skip_plugins   =    ; default empty; a regexp of plugin names to exclude
   skip_prereqs   =    ; default empty; corresponds to AutoPrereqs:skip
@@ -483,7 +494,7 @@ This bundle is roughly equivalent to:
   ; use W3CDTF format for release timestamps (for unambiguous dates)
   time_zone = UTC
   format    = %-9v %{yyyy-MM-dd'T'HH:mm:ss'Z'}d
-  [OurPkgVersion]         ; inject $VERSION at '# VERSION' comments
+  [PkgVersion]            ; inject $VERSION (use OurPkgVersion if 'placeholder_comments')
   [Prepender]             ; add header to source code files
 
   [PodWeaver]             ; munge POD in all modules
@@ -645,7 +656,7 @@ progress on the request by the system.
 
 L<https://github.com/rwstauner/Dist-Zilla-PluginBundle-Author-RWSTAUNER>
 
-  git clone https://github.com/rwstauner/Dist-Zilla-PluginBundle-Author-RWSTAUNER
+  git clone https://github.com/rwstauner/Dist-Zilla-PluginBundle-Author-RWSTAUNER.git
 
 =head1 AUTHOR
 
